@@ -1,6 +1,5 @@
 import typer
 
-
 llm = typer.Typer(short_help="The LLM management.")
 
 
@@ -11,10 +10,28 @@ def serve(
     parallal_size: int = typer.Option(1, help="The number of GPUs to use."),
     host: str = typer.Option("0.0.0.0", help="The host of the server."),
     port: int = typer.Option(8000, help="The port of the server."),
+    quantization: str = typer.Option(None, help="The quantization method to use."),
+    load_format: str = typer.Option(None, help="The load format to use."),
+    enforce_eager: bool = typer.Option(
+        False, help="Whether to enforce eager execution."
+    ),
+    max_num_seq: int = typer.Option(2, help="The maximum number of sequences."),
+    max_model_len: int = typer.Option(4096, help="The maximum model length."),
 ):
     from mw_python_sdk.llm.inference import serve
 
-    serve(model, model_name=model_name, host=host, port=port)
+    serve(
+        model,
+        model_name=model_name,
+        host=host,
+        port=port,
+        max_num_seq=max_num_seq,
+        max_model_len=max_model_len,
+        tensor_parallel_size=parallal_size,
+        quantization=quantization,
+        load_format=load_format,
+        enforce_eager=enforce_eager,
+    )
 
 
 datasets = typer.Typer(short_help="The datasets management.")
@@ -92,5 +109,13 @@ app = typer.Typer()
 app.add_typer(llm, name="llm")
 app.add_typer(datasets, name="ds")
 
+
+@app.command(short_help="Set up a fast reverse proxy.")
+def frp(port: int = typer.Argument(..., help="The port of the proxy.")):
+    from mw_python_sdk.frp import fast_reverse_proxy
+
+    fast_reverse_proxy(port)
+
+
 if __name__ == "__main__":
     app()
